@@ -3,9 +3,10 @@
  *
  * This file is part of Xml Copy Editor.
  *
- * Xml Copy Editor is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 of the License.
+ * Xml Copy Editor is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  *
  * Xml Copy Editor is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -33,6 +34,7 @@ class AssociateDialog : public wxDialog
 		    const wxString& typeParameter = _T ( "All" ),
 		    const wxString& extensionParameter = _T ( "*.*" ),
 		    const wxString& urlParameter = wxEmptyString,
+		    wxString *lastDir = NULL,
 		    bool auxNeededParameter = false,
 		    const wxString& auxLabelTextParameter = wxEmptyString,
 		    const wxString& auxParameter = wxEmptyString );
@@ -54,6 +56,7 @@ class AssociateDialog : public wxDialog
 		wxButton *browseButton;
 		wxStaticText *urlLabel, *auxLabel;
 		wxString title, label, type, extension, url;
+		wxString *mLastDir;
 		bool auxNeeded;
 		wxString auxLabelText, aux;
 		DECLARE_EVENT_TABLE()
