@@ -3,9 +3,10 @@
  *
  * This file is part of Xml Copy Editor.
  *
- * Xml Copy Editor is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 of the License.
+ * Xml Copy Editor is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  *
  * Xml Copy Editor is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -32,7 +33,8 @@ enum
 	ID_FINDREPLACE_REPLACE,
 	ID_FINDREPLACE_REPLACE_ALL,
 	ID_FINDREPLACE_MATCH_CASE,
-	ID_FINDREPLACE_REGEX
+	ID_FINDREPLACE_REGEX,
+	ID_FINDREPLACE_CLOSE
 };
 
 class FindReplacePanel : public wxPanel
@@ -48,6 +50,7 @@ class FindReplacePanel : public wxPanel
 		void OnFindNext ( wxCommandEvent& event );
 		void OnReplace ( wxCommandEvent& event );
 		void OnReplaceAll ( wxCommandEvent& event );
+		void OnClose ( wxCommandEvent& event );
 		void focusOnFind();
 		bool getIncrementalFind();
 		bool getRegex();
@@ -69,6 +72,7 @@ class FindReplacePanel : public wxPanel
 		bool matchCaseMemory, regexMemory;
 		bool incrementalFind, isReplaceDialog, notFoundSet, isRegex;
 
+		void OnCharHook ( wxKeyEvent& event );
 		void OnIdle ( wxIdleEvent& event );
 		void sendFindEvent ( size_t flags );
 
