@@ -137,7 +137,7 @@ void HouseStyle::collectRules ( const std::string& fileName,
 	if ( !ReadFile::run ( filePath, buffer ) )
 		return;
 
-	std::auto_ptr<XmlRuleReader> xrr ( new XmlRuleReader (
+	boost::scoped_ptr<XmlRuleReader> xrr ( new XmlRuleReader (
 	                                       dictionary,
 	                                       passiveDictionary,
 	                                       ruleVector ) );
@@ -145,9 +145,9 @@ void HouseStyle::collectRules ( const std::string& fileName,
 	{
 		std::string report = xrr->getIncorrectPatternReport();
 		if ( report != "" )
-			throw runtime_error ( report.c_str() );
+			throw std::runtime_error ( report.c_str() );
 		else
-			throw runtime_error ( ( const char * ) xrr->getLastError().utf8_str() );
+			throw std::runtime_error ( ( const char * ) xrr->getLastError().utf8_str() );
 	}
 
 	// add current file to exclude set
