@@ -3,9 +3,10 @@
  *
  * This file is part of Xml Copy Editor.
  *
- * Xml Copy Editor is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 of the License.
+ * Xml Copy Editor is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  *
  * Xml Copy Editor is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -26,8 +27,11 @@
 using namespace std;
 
 HouseStyleReader::HouseStyleReader (
-    map<string, map<string, set<string> > > &m
-) : WrapExpat ( true ), ud ( new HouseStyleReaderData() )
+	map<string, map<string, set<string> > > &m
+	, const char *encoding /*= NULL*/
+	)
+	: WrapExpat ( encoding, true )
+	, ud ( new HouseStyleReaderData() )
 {
 	ud->setState ( STATE_UNKNOWN );
 	ud->depth = ud->cutoffDepth = 0;
