@@ -25,11 +25,13 @@
 #include <map>
 #include <set>
 #include <vector>
-#include <memory>
-#include <expat.h>
+#include <boost/scoped_ptr.hpp>
 #include "wrapexpat.h"
 
-using namespace std;
+using std::map;
+using std::vector;
+using std::set;
+using std::string;
 
 struct HouseStyleReaderData : public ParserData
 {
@@ -50,7 +52,7 @@ class HouseStyleReader : public WrapExpat
 		virtual ~HouseStyleReader();
 		void getNodeVector ( vector<pair<string, unsigned> > &v );
 	private:
-		std::auto_ptr<HouseStyleReaderData> ud;
+		boost::scoped_ptr<HouseStyleReaderData> ud;
 		enum
 		{
 			STATE_UNKNOWN,
