@@ -23,13 +23,14 @@
 
 #include <set>
 #include <string>
-#include <memory>
-#include <expat.h>
+#include <boost/scoped_ptr.hpp>
 #include "wrapexpat.h"
 #include "wrapregex.h"
 #include "contexthandler.h"
 
-using namespace std;
+using std::vector;
+using std::set;
+using std::string;
 
 struct HouseStyleWriterData : public ParserData
 {
@@ -45,7 +46,7 @@ class HouseStyleWriter : public WrapExpat
 		~HouseStyleWriter();
 		string getOutput();
 	private:
-		std::auto_ptr<HouseStyleWriterData> hswd;
+		boost::scoped_ptr<HouseStyleWriterData> hswd;
 		enum
 		{
 			STATE_UNKNOWN,
