@@ -3,9 +3,10 @@
  *
  * This file is part of Xml Copy Editor.
  *
- * Xml Copy Editor is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 of the License.
+ * Xml Copy Editor is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  *
  * Xml Copy Editor is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -71,7 +72,8 @@ InsertPanel::InsertPanel (
 void InsertPanel::update (
     XmlDoc *docParameter,
     const wxString& parentParameter,
-    const wxString& grandparentParameter )
+    const wxString& grandparentParameter,
+    bool forced )
 {
 	doc = docParameter;
 	parent = parentParameter;
@@ -89,7 +91,7 @@ void InsertPanel::update (
 		return;
 	}
 
-	bool refreshEntities = false;
+	bool refreshEntities = forced;
 	if ( doc != lastDoc )
 	{
 		refreshEntities = true;
@@ -102,18 +104,14 @@ void InsertPanel::update (
 		lastDoc = doc;
 		const std::set<wxString> &entitySet = doc->getEntitySet();
 		std::set<wxString>::const_iterator it;
-		for ( it = entitySet.begin(); it != entitySet.end(); it++ )
+		for ( it = entitySet.begin(); it != entitySet.end(); ++it )
 			list->Append ( *it );
 		list->Show ( true );
-#if wxCHECK_VERSION(2,9,0)
-		list->Update();
-#else
 		sizer->Layout();
-#endif
 		return;
 	}
 
-	if ( parent == lastParent )
+	if ( parent == lastParent && !refreshEntities )
 		return;
 	lastParent = parent;
 
@@ -139,14 +137,10 @@ void InsertPanel::update (
 		return;
 	}
 	std::set<wxString>::const_iterator it;
-	for ( it = elementSet.begin(); it != elementSet.end(); it++ )
+	for ( it = elementSet.begin(); it != elementSet.end(); ++it )
 		list->Append ( *it );
 	list->Show ( true );
-#if wxCHECK_VERSION(2,9,0)
-	list->Update();
-#else
 	sizer->Layout();
-#endif
 }
 
 void InsertPanel::OnEnter ( wxCommandEvent& event )
@@ -179,7 +173,7 @@ void InsertPanel::handleChoice ( const wxString& choice )
 		return;
 
 	if ( parentWindow )
-		parentWindow->closePane();
+		parentWindow->closeMessagePane();
 
 	switch ( type )
 	{
