@@ -3,9 +3,10 @@
  *
  * This file is part of Xml Copy Editor.
  *
- * Xml Copy Editor is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 of the License.
+ * Xml Copy Editor is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  *
  * Xml Copy Editor is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -21,6 +22,7 @@
 #include "xmldoc.h"
 
 BEGIN_EVENT_TABLE ( LocationPanel, wxPanel )
+	EVT_SYS_COLOUR_CHANGED ( LocationPanel::OnSysColourChanged )
 END_EVENT_TABLE()
 
 LocationPanel::LocationPanel ( wxWindow *parentWindowParameter, int id ) :
@@ -59,6 +61,10 @@ LocationPanel::LocationPanel ( wxWindow *parentWindowParameter, int id ) :
 	//structureEdit->SetWrapVisualFlags ( wxSTC_WRAPVISUALFLAG_START );
 	structureEdit->SetTabWidth ( 2 );
 	structureEdit->SetIndentationGuides ( true );
+	structureEdit->SetLexer ( wxSTC_LEX_NULL );
+
+	wxSysColourChangedEvent event;
+	OnSysColourChanged ( event );
 
 	sizer->Add ( edit, 0, wxGROW | wxTOP, 0 );
 	sizer->Add ( structureEdit, 1, wxGROW | wxTOP, 0 );
@@ -90,11 +96,7 @@ void LocationPanel::update (
 			structureEdit->SetReadOnly ( false );
 			structureEdit->SetText ( structure );
 			structureEdit->SetReadOnly ( true );
-#if wxCHECK_VERSION(2,9,0)
-			structureEdit->Update();
-#else
 			sizer->Layout();
-#endif
 		}
 		else
 		{
@@ -118,7 +120,7 @@ void LocationPanel::indentStructure ( wxString& structure )
 
 	int count = 0;
 	bool justSeenContent = false;
-	for ( ; *s; s++, count++)
+	for ( ; *s; ++s, count++)
 	{
 		if (*s == '(')
 		{
@@ -173,3 +175,12 @@ void LocationPanel::indentStructure ( wxString& structure )
 	}
 	structure = indented;
 }
+
+void LocationPanel::OnSysColourChanged ( wxSysColourChangedEvent &WXUNUSED ( event ) )
+{
+	wxColor clrWnd = wxSystemSettings::GetColour ( wxSYS_COLOUR_WINDOW );
+	wxColor clrText = wxSystemSettings::GetColour ( wxSYS_COLOUR_WINDOWTEXT );
+	structureEdit->StyleSetForeground ( wxSTC_STYLE_DEFAULT, clrText );
+	structureEdit->StyleSetBackground ( wxSTC_STYLE_DEFAULT, clrWnd );
+	structureEdit->StyleClearAll();
+}
