@@ -3,9 +3,10 @@
  *
  * This file is part of Xml Copy Editor.
  *
- * Xml Copy Editor is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 of the License.
+ * Xml Copy Editor is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  *
  * Xml Copy Editor is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -34,6 +35,7 @@
 
 #include <xercesc/sax2/SAX2XMLReader.hpp>
 #include <xercesc/sax2/DefaultHandler.hpp>
+#include <xercesc/dom/DOMElement.hpp>
 #include "xercescatalogresolver.h"
 
 using namespace xercesc;
@@ -44,7 +46,7 @@ class MySAX2Handler : public DefaultHandler
 		MySAX2Handler()
 		{
 			mEOL = _T("\n");
-			resetErrors();
+			reset();
 		}
 		void error ( const SAXParseException& e )
 		{
@@ -60,7 +62,7 @@ class MySAX2Handler : public DefaultHandler
 			logError ( _("FatalError"), wxLOG_FatalError, e );
 			throw e;
 		}
-		void resetErrors()
+		void reset()
 		{
 			mErrors.clear();
 			mErrorPosition = std::make_pair ( 1, 1 );
@@ -98,7 +100,9 @@ class WrapXerces : private boost::noncopyable
 
 		WrapXerces();
 		virtual ~WrapXerces();
+		// Returns true if the file is valid. But there can be warnings
 		bool validate ( const wxString &fileName );
+		// Returns true if the content is valid. But there can be warnings
 		bool validateMemory ( const char *utf8Buffer, size_t len,
 		    const wxString &fileName, wxThread *thread = NULL,
 		    bool forceGrammarCheck = true, /* Must specify a grammar */
@@ -122,6 +126,16 @@ class WrapXerces : private boost::noncopyable
 		// Returns original value
 		static bool enableNetwork ( bool enable = true );
 
+		static xercesc::InputSource *resolveEntity (
+			const wxString &publicId,
+			const wxString &systemId,
+			const wxString &fileName );
+
+		static DOMElement *getFirstElementChild ( const DOMElement &element );
+		static DOMElement *getFirstElementChild ( const DOMNode *n );
+		static DOMElement *getNextElementSibling ( const DOMElement &element );
+		static DOMNode *getNextLogicalSibling ( const DOMNode* n );
+
 	private:
 		static const wxMBConv &getMBConv();
 		static XMLNetAccessor *mOriginalNetAccessor;
