@@ -21,6 +21,10 @@
 #ifndef XMLCOPYEDITOR_H
 #define XMLCOPYEDITOR_H
 
+#ifdef __WXOSX__
+#define wxMAC_USE_NATIVE_TOOLBAR 1
+#endif
+
 #define NEWFINDREPLACE 1
 
 #include <wx/wx.h>
@@ -47,13 +51,14 @@
 #include <string>
 #include <set>
 #include <map>
-#include <memory>
 #include <vector>
 #include <stdexcept>
+#include <boost/scoped_ptr.hpp>
 #include "xmldoc.h"
 #include "myhtmlpane.h"
 #include "xmlencodinghandler.h"
 #include <wx/aui/framemanager.h>
+#include <xercesc/util/XercesDefs.hpp>
 
 enum
 {
@@ -194,7 +199,7 @@ class MyApp : public wxApp
 		MyServer *server;
 		bool singleInstanceCheck;
 		int lang;
-		std::auto_ptr<wxFileConfig> config;
+		boost::scoped_ptr<wxFileConfig> config;
 };
 
 // forward declarations
@@ -369,9 +374,9 @@ class MyFrame : public wxFrame
 #ifndef __WXDEBUG__
 		wxLogNull logTarget;
 #endif
-		std::auto_ptr<wxHtmlEasyPrinting> htmlPrinting;
-		std::auto_ptr<wxFindReplaceDialog> findDialog;
-		std::auto_ptr<wxHtmlHelpController> helpController;
+		boost::scoped_ptr<wxHtmlEasyPrinting> htmlPrinting;
+		boost::scoped_ptr<wxFindReplaceDialog> findDialog;
+		boost::scoped_ptr<wxHtmlHelpController> helpController;
 
 		wxBoxSizer *frameSizer;
 		wxMenuBar *menuBar;
@@ -397,7 +402,6 @@ class MyFrame : public wxFrame
 		std::map<int, wxString> validationPresetMap;
 #ifdef __WXMSW__
 		struct MyCompare
-				: public std::binary_function<wxString, wxString, bool>
 		{
 			bool operator() ( const wxString &x, const wxString &y ) const
 			{
@@ -432,6 +436,7 @@ class MyFrame : public wxFrame
 		  rngDir,
 		  htmlDir,
 		  pngDir,
+		  xpmDir,
 		  daisyDir,
 		  xpathExpression,
 		  lastDtdPublic,
@@ -476,6 +481,9 @@ class MyFrame : public wxFrame
 		showFullPathOnFrame,
 		findRegex,
 		commandSync,
+#if defined(XERCES_HAVE_SSE2_INTRINSIC) && defined(__WXDEBUG__)
+		xercescSSE2Warning,
+#endif
 		exportQuiet,
 		exportMp3Album,
 		exportSuppressOptional,
@@ -483,8 +491,7 @@ class MyFrame : public wxFrame
 		exportEpub,
 		exportRtf,
 		exportDoc,
-		exportFullDaisy,
-		xercescSSE2Warning;
+		exportFullDaisy;
 		wxBitmap newBitmap,
 		new16Bitmap,
 		openBitmap,
