@@ -3,9 +3,10 @@
  *
  * This file is part of Xml Copy Editor.
  *
- * Xml Copy Editor is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 of the License.
+ * Xml Copy Editor is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  *
  * Xml Copy Editor is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -23,8 +24,9 @@
 #include <expat.h>
 #include "xmlencodingspy.h"
 
-XmlEncodingSpy::XmlEncodingSpy() :
-		d ( new EncodingData() )
+XmlEncodingSpy::XmlEncodingSpy ( const char *encoding )
+	: WrapExpat ( encoding )
+	, d ( new EncodingData() )
 {
 	XML_SetUserData ( p, d.get() );
 	XML_SetXmlDeclHandler ( p, xmldeclhandler );
