@@ -3,9 +3,10 @@
  *
  * This file is part of Xml Copy Editor.
  *
- * Xml Copy Editor is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 of the License.
+ * Xml Copy Editor is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  *
  * Xml Copy Editor is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -23,7 +24,9 @@
 #include <expat.h>
 #include "xmlparseschemans.h"
 
-XmlParseSchemaNs::XmlParseSchemaNs() : WrapExpat ( false ), d ( new ParseSchemaNsData() )
+XmlParseSchemaNs::XmlParseSchemaNs()
+    : WrapExpat ( NULL, false )
+    , d ( new ParseSchemaNsData() )
 {
 	d->p = p; // set parser for XML_StopParser call
 	XML_SetUserData ( p, d.get() );
@@ -43,7 +46,7 @@ void XMLCALL XmlParseSchemaNs::start ( void *data,
 
 	while ( *attr )
 	{
-		d->attributeVector.push_back ( make_pair ( *attr, * ( attr + 1 ) ) );
+		d->attributeVector.push_back ( std::make_pair ( *attr, * ( attr + 1 ) ) );
 		attr += 2;
 	}
 	XML_StopParser ( d->p, false );
