@@ -25,7 +25,7 @@
 #include <vector>
 #include <expat.h>
 #include <string>
-#include <memory>
+#include <boost/scoped_ptr.hpp>
 #include "wrapexpat.h"
 
 struct ProdnoteData : public ParserData
@@ -52,7 +52,7 @@ class XmlProdnote : public WrapExpat
 			return d->encoding;
 		}
 	private:
-		std::auto_ptr<ProdnoteData> d;
+		boost::scoped_ptr<ProdnoteData> d;
 		std::string encoding, element, attribute;
 		static void XMLCALL xmldeclhandler (
 		    void *data,
