@@ -3,9 +3,10 @@
  * 
  * This file is part of Xml Copy Editor.
  * 
- * Xml Copy Editor is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 of the License.
+ * Xml Copy Editor is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  * 
  * Xml Copy Editor is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -24,8 +25,13 @@
 #include <expat.h>
 #include "xmlschemaparser.h"
 
-XmlSchemaParser::XmlSchemaParser ( PromptGeneratorData *data, bool nameSpaceAware ) :
-        WrapExpat ( nameSpaceAware ), d ( new SchemaParserData )
+XmlSchemaParser::XmlSchemaParser (
+    PromptGeneratorData *data,
+    const char *encoding,
+    bool nameSpaceAware
+    )
+    : WrapExpat ( encoding, nameSpaceAware )
+    , d ( new SchemaParserData )
 {
     d->promptData = data;
     d->setState ( STATE_UNKNOWN );
